@@ -136,7 +136,7 @@ pub fn display_command<T: AsRef<OsStr> + Debug, U: AsRef<OsStr> + Debug>(
     args: &[U],
 ) -> String {
     std::iter::once(cmd.as_ref())
-        .chain(args.iter().map(std::convert::AsRef::as_ref))
+        .chain(args.iter().map(AsRef::as_ref))
         .map(|i| i.to_string_lossy().into_owned())
         .collect::<Vec<String>>()
         .join(" ")
@@ -393,6 +393,10 @@ WebAssembly: unavailable
             stdout: String::from("Python 3.8.0\n"),
             stderr: String::default(),
         }),
+        "quarto --version" => Some(CommandOutput {
+            stdout: String::from("1.4.549\n"),
+            stderr: String::default(),
+        }),
         "R --version" => Some(CommandOutput {
             stdout: String::default(),
             stderr: String::from(
@@ -645,7 +649,7 @@ fn render_time_component((component, suffix): (&u128, &&str)) -> String {
 }
 
 pub fn home_dir() -> Option<PathBuf> {
-    dirs_next::home_dir()
+    dirs::home_dir()
 }
 
 const HEXTABLE: &[char] = &[
